searchData={"items":[{"type":"module","title":"Number","doc":"`Number` provides functions to convert numbers into a variety of different\nformats. Ultimately, it aims to be a partial clone of\n[ActionView::Helpers::NumberHelper](http://api.rubyonrails.org/classes/ActionView/Helpers/NumberHelper.html)\nfrom Rails.\n\nIf you want to import all of the functions provided by `Number`, simply `use`\nit in your module:\n\n    defmodule MyModule do\n      use Number\n    end\n\nMore likely, you'll want to import the functions you want from one of\n`Number`'s submodules.\n\n    defmodule MyModule do\n      import Number.Currency\n    end","ref":"Number.html"},{"type":"module","title":"Configuration - Number","doc":"Some of `Number`'s behavior can be configured through Mix. Each submodule\ncontains documentation on how to configure it.","ref":"Number.html#module-configuration"},{"type":"type","title":"Number.t/0","doc":"","ref":"Number.html#t:t/0"},{"type":"protocol","title":"Number.Conversion","doc":"Converts values to formats consumable by Number.","ref":"Number.Conversion.html"},{"type":"function","title":"Number.Conversion.to_decimal/1","doc":"Converts a value to a Decimal.","ref":"Number.Conversion.html#to_decimal/1"},{"type":"function","title":"Number.Conversion.to_float/1","doc":"Converts a value to a Float.","ref":"Number.Conversion.html#to_float/1"},{"type":"type","title":"Number.Conversion.t/0","doc":"All the types that implement this protocol.","ref":"Number.Conversion.html#t:t/0"},{"type":"module","title":"Number.Currency","doc":"Provides functions for converting numbers into formatted currency strings.","ref":"Number.Currency.html"},{"type":"function","title":"Number.Currency.number_to_currency/2","doc":"Converts a number to a formatted currency string.","ref":"Number.Currency.html#number_to_currency/2"},{"type":"function","title":"Parameters - Number.Currency.number_to_currency/2","doc":"* `number` - A float or integer to convert.\n\n* `options` - A keyword list of options. See the documentation of all\n  available options below for more information.","ref":"Number.Currency.html#number_to_currency/2-parameters"},{"type":"function","title":"Options - Number.Currency.number_to_currency/2","doc":"* `:unit` - The currency symbol to use. Default: \"$\"\n\n* `:precision` - The number of decimal places to include. Default: 2\n\n* `:delimiter` - The character to use to delimit the number by thousands.\n  Default: \",\"\n\n* `:separator` - The character to use to separate the number from the decimal\n  places. Default: \".\"\n\n* `:format` - The format of the number. This can be used to put the currency\n  symbol in a different place.  See the examples for usage. There are two\n  supported format string placeholders:\n    * `%u` - Represents the currency symbol, or unit.\n    * `%n` - Represents the number.\n\n* `:negative_format` - The format of the number when it is negative. Uses the\n  same formatting placeholders as the `:format` option.\n\nDefault config for these options can be specified in the `Number`\napplication configuration.\n\n    config :number,\n      currency: [\n        unit: \"£\",\n        precision: 2,\n        delimiter: \",\",\n        separator: \".\",\n        format: \"%u%n\",           # \"£30.00\"\n        negative_format: \"(%u%n)\" # \"(£30.00)\"\n      ]","ref":"Number.Currency.html#number_to_currency/2-options"},{"type":"function","title":"Examples - Number.Currency.number_to_currency/2","doc":"iex> Number.Currency.number_to_currency(nil)\n    nil\n\n    iex> Number.Currency.number_to_currency(1000)\n    \"$1,000.00\"\n\n    iex> Number.Currency.number_to_currency(1000, unit: \"£\")\n    \"£1,000.00\"\n\n    iex> Number.Currency.number_to_currency(-1000)\n    \"-$1,000.00\"\n\n    iex> Number.Currency.number_to_currency(-234234.23)\n    \"-$234,234.23\"\n\n    iex> Number.Currency.number_to_currency(1234567890.50)\n    \"$1,234,567,890.50\"\n\n    iex> Number.Currency.number_to_currency(1234567890.506)\n    \"$1,234,567,890.51\"\n\n    iex> Number.Currency.number_to_currency(1234567890.506, precision: 3)\n    \"$1,234,567,890.506\"\n\n    iex> Number.Currency.number_to_currency(-1234567890.50, negative_format: \"(%u%n)\")\n    \"($1,234,567,890.50)\"\n\n    iex> Number.Currency.number_to_currency(1234567890.50, unit: \"R$\", separator: \",\", delimiter: \"\")\n    \"R$1234567890,50\"\n\n    iex> Number.Currency.number_to_currency(1234567890.50, unit: \"R$\", separator: \",\", delimiter: \"\", format: \"%n %u\")\n    \"1234567890,50 R$\"\n\n    iex> Number.Currency.number_to_currency(Decimal.from_float(50.0))\n    \"$50.00\"\n\n    iex> Number.Currency.number_to_currency(Decimal.from_float(-100.01))\n    \"-$100.01\"\n\n    iex> Number.Currency.number_to_currency(Decimal.from_float(-100.01), unit: \"$\", separator: \",\", delimiter: \".\", negative_format: \"- %u %n\")\n    \"- $ 100,01\"","ref":"Number.Currency.html#number_to_currency/2-examples"},{"type":"module","title":"Number.Delimit","doc":"Provides functions to delimit numbers into strings.","ref":"Number.Delimit.html"},{"type":"function","title":"Number.Delimit.number_to_delimited/2","doc":"Formats a number into a string with grouped thousands using `delimiter`.","ref":"Number.Delimit.html#number_to_delimited/2"},{"type":"function","title":"Parameters - Number.Delimit.number_to_delimited/2","doc":"* `number` - A float or integer to convert.\n\n* `options` - A keyword list of options. See the documentation of all\n  available options below for more information.","ref":"Number.Delimit.html#number_to_delimited/2-parameters"},{"type":"function","title":"Options - Number.Delimit.number_to_delimited/2","doc":"* `:precision` - The number of decimal places to include. Default: 2\n\n* `:delimiter` - The character to use to delimit the number by thousands.\n  Default: \",\"\n\n* `:separator` - The character to use to separate the number from the decimal\n  places. Default: \".\"\n\nDefault configuration for these options can be specified in the `Number`\napplication configuration.\n\n    config :number,\n      delimit: [\n        precision: 3,\n        delimiter: \",\",\n        separator: \".\"\n      ]","ref":"Number.Delimit.html#number_to_delimited/2-options"},{"type":"function","title":"Examples - Number.Delimit.number_to_delimited/2","doc":"iex> Number.Delimit.number_to_delimited(nil)\n    nil\n\n    iex> Number.Delimit.number_to_delimited(998.999)\n    \"999.00\"\n\n    iex> Number.Delimit.number_to_delimited(-234234.234)\n    \"-234,234.23\"\n\n    iex> Number.Delimit.number_to_delimited(\"998.999\")\n    \"999.00\"\n\n    iex> Number.Delimit.number_to_delimited(\"-234234.234\")\n    \"-234,234.23\"\n\n    iex> Number.Delimit.number_to_delimited(12345678)\n    \"12,345,678.00\"\n\n    iex> Number.Delimit.number_to_delimited(12345678.05)\n    \"12,345,678.05\"\n\n    iex> Number.Delimit.number_to_delimited(12345678, delimiter: \".\")\n    \"12.345.678.00\"\n\n    iex> Number.Delimit.number_to_delimited(12345678, delimiter: \",\")\n    \"12,345,678.00\"\n\n    iex> Number.Delimit.number_to_delimited(12345678.05, separator: \" \")\n    \"12,345,678 05\"\n\n    iex> Number.Delimit.number_to_delimited(98765432.98, delimiter: \" \", separator: \",\")\n    \"98 765 432,98\"\n\n    iex> Number.Delimit.number_to_delimited(Decimal.from_float(9998.2))\n    \"9,998.20\"\n\n    iex> Number.Delimit.number_to_delimited \"123456789555555555555555555555555\"\n    \"123,456,789,555,555,555,555,555,555,555,555.00\"\n\n    iex> Number.Delimit.number_to_delimited Decimal.new(\"123456789555555555555555555555555\")\n    \"123,456,789,555,555,555,555,555,555,555,555.00\"","ref":"Number.Delimit.html#number_to_delimited/2-examples"},{"type":"module","title":"Number.Human","doc":"Provides functions for converting numbers into more human readable strings.","ref":"Number.Human.html"},{"type":"function","title":"Number.Human.number_to_human/2","doc":"Formats and labels a number with the appropriate English word.","ref":"Number.Human.html#number_to_human/2"},{"type":"function","title":"Examples - Number.Human.number_to_human/2","doc":"iex> Number.Human.number_to_human(nil)\n    nil\n\n    iex> Number.Human.number_to_human(123)\n    \"123.00\"\n\n    iex> Number.Human.number_to_human(1234)\n    \"1.23 Thousand\"\n\n    iex> Number.Human.number_to_human(999001)\n    \"999.00 Thousand\"\n\n    iex> Number.Human.number_to_human(1234567)\n    \"1.23 Million\"\n\n    iex> Number.Human.number_to_human(1234567890)\n    \"1.23 Billion\"\n\n    iex> Number.Human.number_to_human(1234567890123)\n    \"1.23 Trillion\"\n\n    iex> Number.Human.number_to_human(1234567890123456)\n    \"1.23 Quadrillion\"\n\n    iex> Number.Human.number_to_human(1234567890123456789)\n    \"1,234.57 Quadrillion\"\n\n    iex> Number.Human.number_to_human(Decimal.new(\"5000.0\"))\n    \"5.00 Thousand\"\n\n    iex> Number.Human.number_to_human('charlist')\n    ** (ArgumentError) number must be a float, integer or implement `Number.Conversion` protocol, was ~c\"charlist\"","ref":"Number.Human.html#number_to_human/2-examples"},{"type":"function","title":"Number.Human.number_to_ordinal/1","doc":"Adds ordinal suffix (st, nd, rd or th) for the number","ref":"Number.Human.html#number_to_ordinal/1"},{"type":"function","title":"Examples - Number.Human.number_to_ordinal/1","doc":"iex> Number.Human.number_to_ordinal(3)\n    \"3rd\"\n\n    iex> Number.Human.number_to_ordinal(1)\n    \"1st\"\n\n    iex> Number.Human.number_to_ordinal(46)\n    \"46th\"\n\n    iex> Number.Human.number_to_ordinal(442)\n    \"442nd\"\n\n    iex> Number.Human.number_to_ordinal(4001)\n    \"4001st\"","ref":"Number.Human.html#number_to_ordinal/1-examples"},{"type":"module","title":"Number.Percentage","doc":"Provides functions for converting numbers into percentages.","ref":"Number.Percentage.html"},{"type":"function","title":"Number.Percentage.number_to_percentage/2","doc":"Formats a number into a percentage string.","ref":"Number.Percentage.html#number_to_percentage/2"},{"type":"function","title":"Parameters - Number.Percentage.number_to_percentage/2","doc":"* `number` - A value to convert. Can be any value that implements\n  `Number.Conversion.to_float/1`.\n\n* `options` - A keyword list of options. See the documentation below for all\n  available options.","ref":"Number.Percentage.html#number_to_percentage/2-parameters"},{"type":"function","title":"Options - Number.Percentage.number_to_percentage/2","doc":"* `:precision` - The number of decimal places to include. Default: 3\n\n* `:delimiter` - The character to use to delimit the number by thousands.\n  Default: \",\"\n\n* `:separator` - The character to use to separate the number from the decimal\n  places. Default: \".\"\n\nDefault configuration for these options can be specified in the `Number`\napplication configuration.\n\n    config :number,\n      percentage: [\n        delimiter: \",\",\n        separator: \".\",\n        precision: 2\n      ]","ref":"Number.Percentage.html#number_to_percentage/2-options"},{"type":"function","title":"Examples - Number.Percentage.number_to_percentage/2","doc":"iex> Number.Percentage.number_to_percentage(nil)\n    nil\n\n    iex> Number.Percentage.number_to_percentage(100)\n    \"100.000%\"\n\n    iex> Number.Percentage.number_to_percentage(\"98\")\n    \"98.000%\"\n\n    iex> Number.Percentage.number_to_percentage(100, precision: 0)\n    \"100%\"\n\n    iex> Number.Percentage.number_to_percentage(1000, delimiter: '.', separator: ',')\n    \"1.000,000%\"\n\n    iex> Number.Percentage.number_to_percentage(302.24398923423, precision: 5)\n    \"302.24399%\"\n\n    iex> Number.Percentage.number_to_percentage(Decimal.from_float(59.236), precision: 2)\n    \"59.24%\"","ref":"Number.Percentage.html#number_to_percentage/2-examples"},{"type":"module","title":"Number.Phone","doc":"Provides functions to convert numbers into formatted phone number strings.","ref":"Number.Phone.html"},{"type":"function","title":"Number.Phone.number_to_phone/2","doc":"Formats a number into a US phone number (e.g., (555) 123-9876). You can\ncustomize the format in the options list.","ref":"Number.Phone.html#number_to_phone/2"},{"type":"function","title":"Parameters - Number.Phone.number_to_phone/2","doc":"* `number` - A float or integer to convert.\n\n* `options` - A keyword list of options. See the documentation of all\n  available options below for more information.","ref":"Number.Phone.html#number_to_phone/2-parameters"},{"type":"function","title":"Options - Number.Phone.number_to_phone/2","doc":"* `:area_code` - Adds parentheses around the area code if `true`.\n\n* `:delimiter` - Specifies the delimiter to use (defaults to “-”).\n\n* `:extension` - Specifies an extension to add to the end of the generated number.\n\n* `:country_code` - Sets the country code for the phone number.\n\nDefault config for these options can be specified in the `Number`\napplication configuration.\n\n    config :number,\n      phone: [\n        area_code: false,\n        delimiter: \"-\",\n        extension: nil,\n        country_code: nil\n      ]","ref":"Number.Phone.html#number_to_phone/2-options"},{"type":"function","title":"Examples - Number.Phone.number_to_phone/2","doc":"iex> Number.Phone.number_to_phone(nil)\n    nil\n\n    iex> Number.Phone.number_to_phone(5551234)\n    \"555-1234\"\n\n    iex> Number.Phone.number_to_phone(\"5551234\")\n    \"555-1234\"\n\n    iex> Number.Phone.number_to_phone(1235551234)\n    \"123-555-1234\"\n\n    iex> Number.Phone.number_to_phone(1235551234, area_code: true)\n    \"(123) 555-1234\"\n\n    iex> Number.Phone.number_to_phone(1235551234, delimiter: \" \")\n    \"123 555 1234\"\n\n    iex> Number.Phone.number_to_phone(1235551234, area_code: true, extension: 555)\n    \"(123) 555-1234 x 555\"\n\n    iex> Number.Phone.number_to_phone(1235551234, area_code: true, extension: 555, country_code: 1)\n    \"+1 (123) 555-1234 x 555\"\n\n    iex> Number.Phone.number_to_phone(1235551234, country_code: 1)\n    \"+1-123-555-1234\"\n\n    iex> Number.Phone.number_to_phone(\"123a456\")\n    \"123a456\"\n\n    iex> Number.Phone.number_to_phone(1235551234, country_code: 1, extension: 1343, delimiter: \".\")\n    \"+1.123.555.1234 x 1343\"","ref":"Number.Phone.html#number_to_phone/2-examples"},{"type":"module","title":"Number.SI","doc":"Provides functions for formatting numbers using SI notation.","ref":"Number.SI.html"},{"type":"function","title":"Number.SI.number_to_si/2","doc":"Format numbers using SI notation","ref":"Number.SI.html#number_to_si/2"},{"type":"function","title":"Parameters - Number.SI.number_to_si/2","doc":"* `number` - A value to convert. Can be any value that implements\n  `Number.Conversion.to_float/1`.\n\n* `options` - A keyword list of options. See the documentation below for all\n  available options.","ref":"Number.SI.html#number_to_si/2-parameters"},{"type":"function","title":"Options - Number.SI.number_to_si/2","doc":"* `:base` - Use 1024 if you wish to format bytes.  Default: 1000\n\n* `:separator` - The string to place between the scaled number and the `prefix\n  + unit`. Perhaps you want a space here. Default: \"\"\n\n* `:unit` - The unit of measurement, e.g. \"M\" for Meters. Default: \"\"\n\n* `:precision` - The number of decimal places to include. Default: 2\n\n* `:trim` - Trim trailing zeros. Default: false\n\nDefault configuration for these options can be specified in the `Number`\napplication configuration.\n\n    config :number,\n      si: [\n        separator: \" \",\n        precision: 4,\n        trim: true\n      ]","ref":"Number.SI.html#number_to_si/2-options"},{"type":"function","title":"Examples - Number.SI.number_to_si/2","doc":"iex> Number.SI.number_to_si(nil)\n    nil\n\n    iex> Number.SI.number_to_si(1210000000, unit: \"W\")\n    \"1.21GW\"\n\n    iex> Number.SI.number_to_si(1210000000, unit: \"W\", precision: 1)\n    \"1.2GW\"\n\n    iex> Number.SI.number_to_si(1210000000, unit: \"W\", precision: 3, separator: \" \")\n    \"1.210 GW\"\n\n    iex> Number.SI.number_to_si(1210000000, unit: \"W\", precision: 5, trim: true)\n    \"1.21GW\"\n\n    iex> Number.SI.number_to_si(1210000000)\n    \"1.21G\"\n\n    iex> Number.SI.number_to_si(Decimal.new(1210000000))\n    \"1.21G\"\n\n    iex> Number.SI.number_to_si('charlist')\n    ** (ArgumentError) number must be a float, integer or implement `Number.Conversion` protocol, was ~c\"charlist\"","ref":"Number.SI.html#number_to_si/2-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [v1.0.5](https://github.com/danielberkompas/number/tree/v1.0.5) (2024-04-06)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v1.0.4...v1.0.5)\n\n**Merged pull requests:**\n\n- ✅ Test against Elixir 1.16 [\\#63](https://github.com/danielberkompas/number/pull/63) ([danielberkompas](https://github.com/danielberkompas))\n- add missing nil support [\\#62](https://github.com/danielberkompas/number/pull/62) ([bkilshaw](https://github.com/bkilshaw))\n\n## [v1.0.4](https://github.com/danielberkompas/number/tree/v1.0.4) (2023-05-26)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v1.0.3...v1.0.4)\n\n**Merged pull requests:**\n\n- :arrow\\_up: Update `ex_doc` [\\#60](https://github.com/danielberkompas/number/pull/60) ([danielberkompas](https://github.com/danielberkompas))\n- :recycle: Replace `Mix.Config` with `Config` [\\#59](https://github.com/danielberkompas/number/pull/59) ([danielberkompas](https://github.com/danielberkompas))\n- :green\\_heart: Update CI settings [\\#58](https://github.com/danielberkompas/number/pull/58) ([danielberkompas](https://github.com/danielberkompas))\n- :label: Use `Number.t` and `Keyword.t` in typespecs [\\#57](https://github.com/danielberkompas/number/pull/57) ([danielberkompas](https://github.com/danielberkompas))\n- Fix percentage spec [\\#56](https://github.com/danielberkompas/number/pull/56) ([fiodorbaczynski](https://github.com/fiodorbaczynski))\n- Update `number_to_phone/2` typespec [\\#52](https://github.com/danielberkompas/number/pull/52) ([lleger](https://github.com/lleger))\n- Misc doc changes [\\#51](https://github.com/danielberkompas/number/pull/51) ([kianmeng](https://github.com/kianmeng))\n\n## [v1.0.3](https://github.com/danielberkompas/number/tree/v1.0.3) (2020-10-01)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v1.0.2...v1.0.3)\n\n**Closed issues:**\n\n- Broken behavior with Decimal version 1.x [\\#47](https://github.com/danielberkompas/number/issues/47)\n- Decimal 2.0 has been released, Number requires ~\\>1.5 [\\#45](https://github.com/danielberkompas/number/issues/45)\n\n**Merged pull requests:**\n\n- \\[\\#47\\] Add compare/2 shim to support Decimal 1.5 [\\#49](https://github.com/danielberkompas/number/pull/49) ([danielberkompas](https://github.com/danielberkompas))\n\n## [v1.0.2](https://github.com/danielberkompas/number/tree/v1.0.2) (2020-09-21)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v1.0.1...v1.0.2)\n\n**Merged pull requests:**\n\n- Dependencies upgrade, Decimal 2.0 [\\#46](https://github.com/danielberkompas/number/pull/46) ([nmbrone](https://github.com/nmbrone))\n\n## [v1.0.1](https://github.com/danielberkompas/number/tree/v1.0.1) (2019-12-06)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v1.0.0...v1.0.1)\n\n**Closed issues:**\n\n- number\\_to\\_delimited shows 2 decimal places.  Readme says otherwise.  [\\#43](https://github.com/danielberkompas/number/issues/43)\n- Changelog entry for 1.0.0 [\\#41](https://github.com/danielberkompas/number/issues/41)\n\n**Merged pull requests:**\n\n- fix: add nil @spec overload to number\\_to\\_delimited [\\#44](https://github.com/danielberkompas/number/pull/44) ([superhawk610](https://github.com/superhawk610))\n\n## [v1.0.0](https://github.com/danielberkompas/number/tree/v1.0.0) (2018-11-28)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.5.7...v1.0.0)\n\n**Closed issues:**\n\n- Rounding fails [\\#38](https://github.com/danielberkompas/number/issues/38)\n\n**Merged pull requests:**\n\n- Fix deprecation warnings from decimal module [\\#40](https://github.com/danielberkompas/number/pull/40) ([akash-akya](https://github.com/akash-akya))\n- Fix Number.SI test failure, upgrade Travis [\\#39](https://github.com/danielberkompas/number/pull/39) ([danielberkompas](https://github.com/danielberkompas))\n\n## [v0.5.7](https://github.com/danielberkompas/number/tree/v0.5.7) (2018-05-17)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.5.6...v0.5.7)\n\n**Merged pull requests:**\n\n- Drop DecimalArithmetic [\\#37](https://github.com/danielberkompas/number/pull/37) ([michalmuskala](https://github.com/michalmuskala))\n\n## [v0.5.6](https://github.com/danielberkompas/number/tree/v0.5.6) (2018-04-19)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.5.5...v0.5.6)\n\n**Merged pull requests:**\n\n- Decimal to currency fix [\\#36](https://github.com/danielberkompas/number/pull/36) ([Eptis](https://github.com/Eptis))\n\n## [v0.5.5](https://github.com/danielberkompas/number/tree/v0.5.5) (2018-02-19)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.5.4...v0.5.5)\n\n**Closed issues:**\n\n- Invalid typespecs [\\#34](https://github.com/danielberkompas/number/issues/34)\n\n**Merged pull requests:**\n\n- Use Number.t to fix type specs [\\#35](https://github.com/danielberkompas/number/pull/35) ([jclem](https://github.com/jclem))\n\n## [v0.5.4](https://github.com/danielberkompas/number/tree/v0.5.4) (2017-09-07)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.5.3...v0.5.4)\n\n**Closed issues:**\n\n- decimal\\_arithmetic is missing from applications list [\\#32](https://github.com/danielberkompas/number/issues/32)\n\n**Merged pull requests:**\n\n- \\[\\#32\\] Switch to `extra_applications` [\\#33](https://github.com/danielberkompas/number/pull/33) ([danielberkompas](https://github.com/danielberkompas))\n\n## [v0.5.3](https://github.com/danielberkompas/number/tree/v0.5.3) (2017-08-30)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.5.2...v0.5.3)\n\n**Closed issues:**\n\n- Deprecation warnings in Elixir 1.5 [\\#30](https://github.com/danielberkompas/number/issues/30)\n- Negative Decimal problem [\\#28](https://github.com/danielberkompas/number/issues/28)\n\n**Merged pull requests:**\n\n- \\[\\#30\\] Fix deprecation warnings on Elixir 1.5 [\\#31](https://github.com/danielberkompas/number/pull/31) ([danielberkompas](https://github.com/danielberkompas))\n\n## [v0.5.2](https://github.com/danielberkompas/number/tree/v0.5.2) (2017-08-05)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.5.1...v0.5.2)\n\n**Closed issues:**\n\n- Number formatting with abbreviations: $1,200,000 -\\> $1.2MM, $5,586 -\\> $5.6k, etc. [\\#26](https://github.com/danielberkompas/number/issues/26)\n\n**Merged pull requests:**\n\n- \\[\\#23\\] Properly handle negative Decimals [\\#29](https://github.com/danielberkompas/number/pull/29) ([danielberkompas](https://github.com/danielberkompas))\n- fix Float.to\\_string warnings for elixir 1.3 [\\#27](https://github.com/danielberkompas/number/pull/27) ([kerryjj](https://github.com/kerryjj))\n- Update readme for Elixir 1.4 instructions. [\\#25](https://github.com/danielberkompas/number/pull/25) ([sergiotapia](https://github.com/sergiotapia))\n\n## [v0.5.1](https://github.com/danielberkompas/number/tree/v0.5.1) (2017-01-17)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.5.0...v0.5.1)\n\n**Closed issues:**\n\n- Add to application list in mix.exs? [\\#23](https://github.com/danielberkompas/number/issues/23)\n\n**Merged pull requests:**\n\n- Fix 1.4 warnings [\\#24](https://github.com/danielberkompas/number/pull/24) ([stuartbain](https://github.com/stuartbain))\n\n## [v0.5.0](https://github.com/danielberkompas/number/tree/v0.5.0) (2016-11-26)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.4.2...v0.5.0)\n\n**Closed issues:**\n\n- Error in hex doc [\\#16](https://github.com/danielberkompas/number/issues/16)\n\n**Merged pull requests:**\n\n- Stop signing with Keybase [\\#22](https://github.com/danielberkompas/number/pull/22) ([danielberkompas](https://github.com/danielberkompas))\n- Number with ordinal suffix [\\#21](https://github.com/danielberkompas/number/pull/21) ([alexfilatov](https://github.com/alexfilatov))\n- Fixed \\#16 [\\#20](https://github.com/danielberkompas/number/pull/20) ([unti1x](https://github.com/unti1x))\n- \\[\\#18\\] Improve precision using Decimal [\\#19](https://github.com/danielberkompas/number/pull/19) ([danielberkompas](https://github.com/danielberkompas))\n- Fix Number.Delimit.number\\_to\\_delimited cannot handle negative in string [\\#17](https://github.com/danielberkompas/number/pull/17) ([raycheung](https://github.com/raycheung))\n\n## [v0.4.2](https://github.com/danielberkompas/number/tree/v0.4.2) (2016-07-02)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.4.1...v0.4.2)\n\n**Fixed bugs:**\n\n- Number.Conversion is not used internally [\\#12](https://github.com/danielberkompas/number/issues/12)\n\n**Closed issues:**\n\n- Module not available in releases if not listed in :applications [\\#14](https://github.com/danielberkompas/number/issues/14)\n\n**Merged pull requests:**\n\n- \\[\\#12\\] Use Number.Conversion properly, support Decimal [\\#15](https://github.com/danielberkompas/number/pull/15) ([danielberkompas](https://github.com/danielberkompas))\n- Don't set display\\_number inside conditional [\\#13](https://github.com/danielberkompas/number/pull/13) ([bratsche](https://github.com/bratsche))\n\n## [v0.4.1](https://github.com/danielberkompas/number/tree/v0.4.1) (2015-12-16)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.4.0...v0.4.1)\n\n**Closed issues:**\n\n- number\\_to\\_human skips some numbers [\\#10](https://github.com/danielberkompas/number/issues/10)\n\n**Merged pull requests:**\n\n- Fix number\\_to\\_human rounding and skipping errors [\\#11](https://github.com/danielberkompas/number/pull/11) ([danielberkompas](https://github.com/danielberkompas))\n- Adds SI.format [\\#9](https://github.com/danielberkompas/number/pull/9) ([stereosteve](https://github.com/stereosteve))\n- Add examples of module usage to README [\\#7](https://github.com/danielberkompas/number/pull/7) ([danielberkompas](https://github.com/danielberkompas))\n- Prettify Docs [\\#6](https://github.com/danielberkompas/number/pull/6) ([danielberkompas](https://github.com/danielberkompas))\n\n## [v0.4.0](https://github.com/danielberkompas/number/tree/v0.4.0) (2015-08-04)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.3.4...v0.4.0)\n\n**Merged pull requests:**\n\n- Add Number.Human.number\\_to\\_human/2 [\\#5](https://github.com/danielberkompas/number/pull/5) ([danielberkompas](https://github.com/danielberkompas))\n- Add Number.Percentage.number\\_to\\_percentage/2 [\\#4](https://github.com/danielberkompas/number/pull/4) ([danielberkompas](https://github.com/danielberkompas))\n\n## [v0.3.4](https://github.com/danielberkompas/number/tree/v0.3.4) (2015-06-10)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.3.3...v0.3.4)\n\n## [v0.3.3](https://github.com/danielberkompas/number/tree/v0.3.3) (2015-06-10)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.3.2...v0.3.3)\n\n## [v0.3.2](https://github.com/danielberkompas/number/tree/v0.3.2) (2015-06-10)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.3.1...v0.3.2)\n\n**Implemented enhancements:**\n\n- Improve Keybase Signature Validation [\\#3](https://github.com/danielberkompas/number/pull/3) ([danielberkompas](https://github.com/danielberkompas))\n\n## [v0.3.1](https://github.com/danielberkompas/number/tree/v0.3.1) (2015-06-10)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.3.0...v0.3.1)\n\n## [v0.3.0](https://github.com/danielberkompas/number/tree/v0.3.0) (2015-06-10)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.2.1...v0.3.0)\n\n**Implemented enhancements:**\n\n- Add `number_to_phone` function [\\#2](https://github.com/danielberkompas/number/pull/2) ([danielberkompas](https://github.com/danielberkompas))\n\n**Merged pull requests:**\n\n- Update .travis.yml [\\#1](https://github.com/danielberkompas/number/pull/1) ([lowks](https://github.com/lowks))\n\n## [v0.2.1](https://github.com/danielberkompas/number/tree/v0.2.1) (2015-06-09)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/v0.2.0...v0.2.1)\n\n## [v0.2.0](https://github.com/danielberkompas/number/tree/v0.2.0) (2015-06-09)\n\n[Full Changelog](https://github.com/danielberkompas/number/compare/b9ed8744fddaaef3a555aa17f82fe8a4772e501f...v0.2.0)\n\n\n\n\\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*","ref":"changelog.html"},{"type":"extras","title":"Number","doc":"# Number\n\n[![Build Status](https://danielberkompas.semaphoreci.com/badges/number/branches/master.svg?style=shields)](https://danielberkompas.semaphoreci.com/projects/number)\n[![Inline docs](http://inch-ci.org/github/danielberkompas/number.svg?branch=master)](http://inch-ci.org/github/danielberkompas/number)\n[![Coverage Status](https://coveralls.io/repos/github/danielberkompas/number/badge.svg?branch=master)](https://coveralls.io/github/danielberkompas/number?branch=master)\n[![Module Version](https://img.shields.io/hexpm/v/number.svg)](https://hex.pm/packages/number)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/number/)\n[![Total Download](https://img.shields.io/hexpm/dt/number.svg)](https://hex.pm/packages/number)\n[![License](https://img.shields.io/hexpm/l/number.svg)](https://github.com/danielberkompas/number/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/danielberkompas/number.svg)](https://github.com/danielberkompas/number/commits/master)\n\n\n`Number` is an [Elixir](https://github.com/elixir-lang/elixir) library which\nprovides functions to convert numbers into a variety of different formats.\nUltimately, it aims to be a partial clone of\n[ActionView::Helpers::NumberHelper](http://api.rubyonrails.org/classes/ActionView/Helpers/NumberHelper.html)\nfrom Rails.\n\n```elixir\nNumber.Currency.number_to_currency(2034.46)\n\"$2,034.46\"\n\nNumber.Phone.number_to_phone(1112223333, area_code: true, country_code: 1)\n\"+1 (111) 222-3333\"\n\nNumber.Percentage.number_to_percentage(100, precision: 0)\n\"100%\"\n\nNumber.Human.number_to_human(1234)\n\"1.23 Thousand\"\n\nNumber.Delimit.number_to_delimited(12345678)\n\"12,345,678\"\n```","ref":"readme.html"},{"type":"extras","title":"Installation - Number","doc":"Get it from Hex:\n\n```elixir\ndefp deps do\n  [{:number, \"~> 1.0.1\"}]\nend\n```\n\nThen run `mix deps.get`.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Number","doc":"If you want to import all of the functions provided by `Number`, simply `use`\nit in your module:\n\n```elixir\ndefmodule MyModule do\n  use Number\nend\n```\n\nMore likely, you'll want to import the functions you want from one of\n`Number`'s submodules.\n\n```elixir\ndefmodule MyModule do\n  import Number.Currency\nend\n```\n\nSee the [Hex documentation](http://hexdocs.pm/number/) for more information\nabout the modules provided by `Number`.","ref":"readme.html#usage"},{"type":"extras","title":"License - Number","doc":"MIT. See [LICENSE](https://github.com/danielberkompas/number/blob/master/LICENSE) for more details.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}